==> openwebbeans-2.0.27-source-release.zip: openwebbeans-2.0.27/webbeans-impl/src/test/java/org/apache/webbeans/test/proxy/ProxyVetoedTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.test.proxy;

import org.apache.webbeans.test.AbstractUnitTest;
import org.apache.webbeans.test.proxy.beans.ApplicationBean;
import org.junit.Assert;
import org.junit.Test;

import javax.enterprise.inject.Vetoed;
import java.util.ArrayList;
import java.util.Collection;

public class ProxyVetoedTest extends AbstractUnitTest
{
    @Test
    public void testVetoedAnnotation()
    {
        Collection<Class<?>> beanClasses = new ArrayList<Class<?>>();
        beanClasses.add(ApplicationBean.class);
        startContainer(beanClasses, null);
        ApplicationBean applicationBean = getInstance(ApplicationBean.class);
        Assert.assertTrue(applicationBean.getClass().getName().contains("Proxy"));
        Assert.assertTrue(applicationBean.getClass().isAnnotationPresent(Vetoed.class));
    }
}

==> openwebbeans-4.0.3-source-release.zip: openwebbeans-4.0.3/webbeans-impl/src/test/java/org/apache/webbeans/test/proxy/ProxyVetoedTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.test.proxy;

import org.apache.webbeans.test.AbstractUnitTest;
import org.apache.webbeans.test.proxy.beans.ApplicationBean;
import org.junit.Assert;
import org.junit.Test;

import jakarta.enterprise.inject.Vetoed;
import java.util.ArrayList;
import java.util.Collection;

public class ProxyVetoedTest extends AbstractUnitTest
{
    @Test
    public void testVetoedAnnotation()
    {
        Collection<Class<?>> beanClasses = new ArrayList<Class<?>>();
        beanClasses.add(ApplicationBean.class);
        startContainer(beanClasses, null);
        ApplicationBean applicationBean = getInstance(ApplicationBean.class);
        Assert.assertTrue(applicationBean.getClass().getName().contains("Proxy"));
        Assert.assertTrue(applicationBean.getClass().isAnnotationPresent(Vetoed.class));
    }
}
